Documentation
¶
Overview ¶
Package featureflags provides feature flag management for Weblens.
Index ¶
Constants ¶
const FeatureFlagCollectionKey = "featureFlags"
FeatureFlagCollectionKey is the database collection name for feature flag document(s).
const FeatureFlagDocumentID = "ff"
FeatureFlagDocumentID is the ID of the main feature flag document.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Bundle ¶
type Bundle struct {
AllowRegistrations bool `bson:"auth.allow_registrations" json:"auth.allow_registrations"`
EnableHDIR bool `bson:"media.hdir_processing_enabled" json:"media.hdir_processing_enabled"`
} // @name Bundle
Bundle represents the application feature flag document.
type FlagKey ¶
type FlagKey = string
FlagKey represents a feature flag key used to identify specific flags.
const ( // AllowRegistrations controls whether new user registration is allowed. AllowRegistrations FlagKey = "auth.allow_registrations" // EnableHDIR controls whether HDIR (high-dynamic-range image rendering) is enabled. EnableHDIR FlagKey = "media.hdir_processing_enabled" )
Feature Flag keys for Weblens settings.
Click to show internal directories.
Click to hide internal directories.