Documentation
¶
Overview ¶
Package routers provides HTTP routing and server startup functionality for the Weblens application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CaptureInterrupt ¶
func CaptureInterrupt() (context.Context, context.CancelFunc)
CaptureInterrupt sets up signal handling for graceful shutdown of the application.
func Start ¶
func Start(opts StartupOpts) error
Start initializes and starts the Weblens application server. The main function calls this to boot up the app, as well as tests.
Types ¶
type StartupOpts ¶
type StartupOpts struct {
Ctx context.Context
Cnf config.Provider
Logger *zerolog.Logger
CancelFunc context.CancelFunc
Started chan context_service.AppContext
}
StartupOpts defines the options for starting the Weblens application server.
Directories
¶
| Path | Synopsis |
|---|---|
|
api
|
|
|
v1
Package v1 provides the version 1 API routes and handlers for the Weblens application.
|
Package v1 provides the version 1 API routes and handlers for the Weblens application. |
|
v1/backup
Package backup provides REST API handlers for backup operations.
|
Package backup provides REST API handlers for backup operations. |
|
v1/file
Package file provides HTTP handlers for file and folder operations in the Weblens API.
|
Package file provides HTTP handlers for file and folder operations in the Weblens API. |
|
v1/history
Package history provides functionalities for managing and retrieving file history.
|
Package history provides functionalities for managing and retrieving file history. |
|
v1/media
Package media provides handlers for media-related API endpoints.
|
Package media provides handlers for media-related API endpoints. |
|
v1/tower
Package tower contains admin REST API handlers for tower management.
|
Package tower contains admin REST API handlers for tower management. |
|
v1/user
Package user provides REST API handlers for user operations.
|
Package user provides REST API handlers for user operations. |
|
v1/websocket
Package websocket provides WebSocket connection handlers and utilities.
|
Package websocket provides WebSocket connection handlers and utilities. |
|
Package router provides HTTP routing and handler functionality for the Weblens application.
|
Package router provides HTTP routing and handler functionality for the Weblens application. |
|
Package test provides testing utilities for Weblens.
|
Package test provides testing utilities for Weblens. |
|
Package web provides HTTP handlers for serving the Weblens web UI and static content.
|
Package web provides HTTP handlers for serving the Weblens web UI and static content. |
Click to show internal directories.
Click to hide internal directories.